<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Salal
 */

if ( ! function_exists( 'salal_fallback_menu' ) ) :
	/**
	 * Display default page as navigation if no custom menu was set
	 */
	function salal_fallback_menu() {
		$pages = wp_list_pages( 'title_li=&echo=0' );
		echo '<ul id="menu-main-navigation" class="main-navigation-menu menu">' .  $pages  . '</ul>';  // WPCS: XSS OK.
	}
endif;


/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function salal_body_classes( $classes ) {

	// Get theme options from database.
	$theme_options = salal_theme_options();

	// Set Theme Layout.
	if ( 'boxed' === $theme_options['theme_layout'] ) {
		$classes[] = 'boxed-theme-layout';
	} elseif ( 'centered' === $theme_options['theme_layout'] ) {
		$classes[] = 'centered-theme-layout';
	} else {
		$classes[] = 'wide-theme-layout';
	}

	
	/** 
	 * Check if sidebar widget area is empty and what template is being used.
	 * Start with the Blog and Archive sidebar position
	 */
	if ( 'right' == $theme_options['sidebar_position'] && ! is_single() ) {
			$classes[] = 'sidebar-right';
	} elseif ( 'left' == $theme_options['sidebar_position'] && ! is_single() ) {
			$classes[] = 'sidebar-left';			
	} elseif ( 'none' == $theme_options['sidebar_position'] && ! is_single() ) {
			$classes[] = 'no-sidebar';			
	} else {
		// fallback
		$classes[] = 'sidebar-right';
	}

	/** 
	 * Check if sidebar widget area is empty and what template is being used.
	 * This is for the Full Post sidebar position
	 */			
	if ( is_single() && 'right' == $theme_options['sidebar_position_post'] ) {
		 $classes[] = 'sidebar-right'; 		 
	} elseif ( is_single() && 'left' == $theme_options['sidebar_position_post'] ) {
		 $classes[] = 'sidebar-left'; 	
	} elseif ( is_single() && 'none' == $theme_options['sidebar_position_post'] ) {
		 $classes[] = 'fullwidth-single-post no-sidebar'; 		 
	} else {
		// fallback
		$classes[] = 'sidebar-right';
	}

	/** 
	 * Check if sidebar widget area is empty and what template is being used.
	 * This is for the Page Templates sidebar position
	 */
	if ( is_page_template( 'templates/template-left-sidebar.php' ) ) {
		$classes[] = 'sidebar-left';		
	} elseif ( is_page_template( 'templates/template-right-sidebar.php' ) ) {
		$classes[] = 'sidebar-right';	
	} elseif ( is_page_template( 'templates/template-short-width.php' ) ) {
		$classes[] = 'no-sidebar';		
	} else {
		// fallback
		$classes[] = 'sidebar-right';
	}

	

	
	// Set Blog Layout.
	if ( 'list' === $theme_options['blog_layout'] ) {
		$classes[] = 'blog-list-layout';
	} elseif ( 'grid' === $theme_options['blog_layout'] ) {
		$classes[] = 'blog-grid-layout';
	} elseif ( 'large' === $theme_options['blog_layout'] ) {
		$classes[] = 'blog-large-layout';
	}
	
	// Set Full Width Single Post
	if ( true === $theme_options['post_layout'] && is_single() ) {
		$classes[] = 'fullwidth-single-post';
	}	


	// Hide Date?
	if ( false === $theme_options['meta_date'] ) {
		$classes[] = 'date-hidden';
	}

	// Hide Author?
	if ( false === $theme_options['meta_author'] ) {
		$classes[] = 'author-hidden';
	}

	// Hide Single Post Category?
	if ( false === $theme_options['post_category'] ) {
		$classes[] = 'post-category-hidden';
	}
	
	// Hide Category?
	if ( false === $theme_options['meta_category'] ) {
		$classes[] = 'categories-hidden';
	}

	// Hide Tags?
	if ( false === $theme_options['meta_tags'] ) {
		$classes[] = 'tags-hidden';
	}

	// Featured Images?
	if ( false === $theme_options['post_image_archives'] ) {
		$classes[] = 'post-thumbnails-hidden';
	}

	// Single Featured Image?
	if ( false === $theme_options['post_image_single'] && is_single() ) {
		$classes[] = 'post-thumbnail-hidden';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	return $classes;
}
add_filter( 'body_class', 'salal_body_classes' );


/**
 * Adds custom classes to the array of post classes.
 *
 * @param array $classes Classes for the post element.
 * @return array
 */
function salal_post_classes( $classes ) {

	// Add comments-off class.
	if ( ! ( comments_open() || get_comments_number() ) ) {
		$classes[] = 'comments-off';
	}

	return $classes;
}
add_filter( 'post_class', 'salal_post_classes' );


/**
 * Hide Elements with CSS.
 *
 * @return void
 */
function salal_hide_elements() {

	// Get theme options from database.
	$theme_options = salal_theme_options();
	$elements = array();

	// Hide Site Title?
	if ( false === $theme_options['site_title'] ) {
		$elements[] = '.site-title';
	}

	// Hide Site Description?
	if ( false === $theme_options['site_description'] ) {
		$elements[] = '.site-description';
	}

	// Hide Post Navigation?
	if ( false === $theme_options['post_navigation'] ) {
		$elements[] = '.single-post .site-main .post-navigation';
	}

	// Allow plugins to add own elements.
	$elements = apply_filters( 'salal_hide_elements', $elements );

	// Return early if no elements are hidden.
	if ( empty( $elements ) ) {
		return;
	}

	// Create CSS.
	$classes = implode( ', ', $elements );
	$custom_css = $classes . ' { position: absolute; clip: rect(1px, 1px, 1px, 1px); width: 1px; height: 1px; overflow: hidden; }';

	// Add Custom CSS.
	wp_add_inline_style( 'salal-stylesheet', $custom_css );
}
add_filter( 'wp_enqueue_scripts', 'salal_hide_elements', 11 );


/**
 * Change excerpt length for default posts
 *
 * @param int $length Length of excerpt in number of words.
 * @return int
 */
function salal_excerpt_length( $length ) {

	if ( is_admin() ) {
		return $length;
	}

	// Get excerpt length from database.
	$excerpt_length = salal_get_option( 'excerpt_length' );

	// Return excerpt text.
	if ( $excerpt_length >= 0 ) :
		return absint( $excerpt_length );
	else :
		return 35; // Number of words.
	endif;
}
add_filter( 'excerpt_length', 'salal_excerpt_length' );


/**
 * Change excerpt more text for posts
 *
 * @param String $more_text Excerpt More Text.
 * @return string
 */
function salal_excerpt_more( $more_text ) {

	if ( is_admin() ) {
		return $more_text;
	}

	return '&hellip;';
}
add_filter( 'excerpt_more', 'salal_excerpt_more' );
